@@ -4,17 +4,14 @@
 #'
 #' @param name Character string, Legend name.
 #' @param label legend labels (expressions).
-#' @param color Colors for the group
 #' @param pch Legend symbol.
-#' @param lty Line type.
 #' @param position Position of the legend, \code{"right"}, \code{"top"},
 #' \code{"bottom"}.
 #' @param hgap Horizontal gap between the legend entries,
 #' see \code{\link[grid]{legendGrob}} for details.
 #' @param vgap Vertical gap between the legend entries,
 #' see \code{\link[grid]{legendGrob}} for details.
-#' @param fontsize Font size of the legend.
-#' @param fontfamily Font family of the legend.
+#' @param gp Graphical parameters.
 #' @param ... Other parameters, not used currently.
 #'
 #' @return A frame grob
@@ -22,14 +19,15 @@
 #' @keywords internal
 legend_grob <- function(name = "",
                         label,
-                        color,
                         position = c("right", "top", "bottom"),
                         hgap = unit(0.1, "lines"), #horizontal gap
                         vgap = unit(0.5, "lines"), #vertical gap
                         pch = 15,
-                        lty = 1,
-                        fontsize = 12,
-                        fontfamily = "",
+                        gp = gpar(lty = 1,
+                                  col = "black",
+                                  fill = "black",
+                                  fontsize = 12,
+                                  fontfamily = ""),
                         ...
 ){
 
@@ -40,14 +38,14 @@ legend_grob <- function(name = "",
                          just = "left",
                          x = 0,
                          y = 0.5,
-                         gp = gpar(fontsize = fontsize,
-                                   fontfamily = fontfamily,
+                         gp = gpar(fontsize = gp$fontsize,
+                                   fontfamily = gp$fontfamily,
                                    fontface = 'bold',
                                    fill = 'black'))
 
   if(position %in% c("top", "bottom")){
     by_row <- FALSE
-    ncol <- length(color)
+    ncol <- length(gp$col)
 
   }else{
     by_row <- TRUE
@@ -57,11 +55,7 @@ legend_grob <- function(name = "",
   leg_grob <- legendGrob(label, pch = pch, ncol = ncol,
                          do.lines = TRUE, byrow = by_row,
                          hgap = hgap, vgap = vgap,
-                         gp = gpar(col = color,
-                                   fill = color,
-                                   lty = lty,
-                                   fontsize = fontsize,
-                                   fontfamily = fontfamily))
+                         gp = gp)
 
   u0 <- unit(0, "npc")
   u1 <- unit(0.02, "npc")
